@@ -26,6 +26,12 @@ utils::globalVariables(c("visit_year", "station_name", "sample_project_name_sv",
   clean_shark4r_cache(days = 1, verbose = FALSE)
 }
 
+.onUnload <- function(libpath) {
+  if (is_check()) {
+    try(clean_shark4r_cache(0, clear_perm_cache = TRUE, verbose = FALSE), silent = TRUE)
+  }
+}
+
 .field_definitions <- list(
   Bacterioplankton = list(
     required = c(
@@ -333,6 +339,7 @@ utils::globalVariables(c("visit_year", "station_name", "sample_project_name_sv",
   "Grey seal"              = "GreySeal",
   "Harbour Porpoise"       = "HarbourPorpoise",
   "Harbour seal"           = "HarbourSeal",
+  "Jellyfish"              = "Jellyfish",
   "Physical and Chemical"  = "PhysicalChemical",
   "Phytoplankton"          = "Phytoplankton",
   "Picoplankton"           = "Picoplankton",
